@@ -11,9 +11,9 @@ plot.bptwin <- function(x,n=50,rg=range(x$B[,1]),xlab="Time",ylab="Concordance",
     b00 <- tail(b0,x$Blen)
     b11 <- tail(b1,x$Blen)
     pr0 <- sapply(as.numeric(B0%*%b00+b0[1]), function(z)
-                  pmvn(upper=rep(z,2),sigma=x$Sigma0))
+                  pbvn(upper=rep(z,2),sigma=x$Sigma0))
     pr1 <- sapply(as.numeric(B0%*%b11+b1[1]), function(z)
-                  pmvn(upper=rep(z,2),sigma=x$Sigma1))
+                  pbvn(upper=rep(z,2),sigma=x$Sigma1))
     plot(pr0~t,type="l", xlab=xlab, ylab=ylab,...)
     lines(pr1~t,type="l",lty=2)
   }
