@@ -3,6 +3,7 @@
 #include <algorithm>
 #include <iostream>
 #include <vector>
+#include <complex.h>
 
 using namespace arma;
 using namespace Rcpp;
@@ -62,6 +63,61 @@ return(val);
 }
 // }}}
 
+// {{{ Complex laplace and derivatives for structured random cif
+cx_double Clapgam(cx_double alpha,cx_double beta,cx_double t)
+{
+cx_double val; 
+val=exp(alpha*(log(beta)-log(beta+t))); 
+return(val); 
+}
+
+cx_double Cilapgam(cx_double alpha,cx_double beta,cx_double y)
+{
+cx_double val; 
+val=beta*(exp(-log(y)/alpha)- (cx_double) 1); 
+return(val); 
+}
+
+cx_double CDilapgam(cx_double alpha,cx_double beta,cx_double y)
+{
+cx_double val; 
+val=beta*exp(-log(y)/alpha)*(log(y)/(alpha*alpha)); 
+return(val); 
+}
+
+cx_double CDbetailapgam(cx_double alpha,cx_double beta,cx_double y)
+{
+cx_double val; 
+val=(exp(-log(y)/alpha)-(cx_double) 1);
+return(val); 
+}
+
+cx_double CDalphalapgam(cx_double alpha,cx_double beta,cx_double t)
+{
+cx_double val; 
+val=exp(alpha*(log(beta)-log(beta+t))); 
+val=(log(beta)-log(beta+t))*val; 
+return(val); 
+}
+
+//cx_double CDbetalapgam(cx_double alpha,cx_double beta,cx_double t)
+//{
+//cx_double val; 
+//val=exp(alpha*(log(beta)-log(beta+t))); 
+//val=alpha*(1/beta-1/(beta+t))*val; 
+//return(val); 
+//}
+//
+//
+//cx_double CDtlapgam(cx_double alpha,cx_double beta,cx_double t)
+//{
+//cx_double val; 
+//val=exp(alpha*(log(beta)-log(beta+t))); 
+//val=-alpha*(1/(beta+t))*val; 
+//return(val); 
+//}
+// }}}
+
 void ckrvdes(vec &alphai,vec &alphak, // {{{
 		double beta, double x,double y,
 		vec &ckij, vec &dckij,vec &rvi,vec &rvk)
@@ -171,9 +227,9 @@ void ckrvdes2(vec &alphai,vec &alphak, // {{{
 		double beta, double x,double y,
 		vec &ckij, vec &dckij,vec &rvi,vec &rvk)
 {
-double val,val1,val2,val3,alphi=0,alphk=0,alph,betai,betak;
+double val,val1,alphi=0,alphk=0,alph,betai,betak;
 double test=1; //lapgam(),ilapgam(),Dtlapgam(), Dalphalapgam(),Dilapgam(),Dbetalapgam(),Dbetailapgam();
-int prv,k,nn; 
+int prv,k,nn,i; 
 //void funkdes2(); 
 
 if (test<1) {
@@ -187,7 +243,7 @@ Rprintf("ckr \n");
 nn=rvi.n_rows; 
 for (k=0;k< nn;k++) {
    alphi=alphi+rvi(k)*alphai(k); 
-   alphk=alphi+rvk(k)*alphak(k); 
+   alphk=alphk+rvk(k)*alphak(k); 
 }
 //alphi=sum(rvi % alphai); alphk=sum(rvk% alphak); 
 //alphi=trans(rvi) * alphai; alphk=trans(rvk) * alphak; 
@@ -208,25 +264,174 @@ val=val*val1;
 }
 ckij(0)=1-exp(-x)-exp(-y)+val; 
 
+// computation of derivatives using cx_double numbers and cx_double functions 
+// goes through the values and adds epislon*i 
+//double epsilon=0; 
+double epsilon=1E-20; 
+epsilon=1E-6; 
+//double Calpht,Calphit,Calphkt,Cbetait,Cbetakt;
+//vec Calphait(prv),Calphakt(prv); 
+//
+//nn=prv; 
+
+//for (i=0;i< prv;i++) { // {{{ 
+//	for (k=0;k< prv;k++) {
+//		Calphait(k)=alphai(k); 
+//		Calphakt(k)=alphak(k); 
+//	}
+////	if ((alphai(i)!=0)) 
+//		Calphait(i)=alphai(i)+epsilon; 
+////	if ((alphak(i)!=0)) 
+//		Calphakt(i)=alphak(i)+epsilon; 
+//
+//	Calphit=0; Calphkt=0; 
+//	for (k=0;k< nn;k++) {
+//	   Calphit=Calphit+rvi(k)*Calphait(k); 
+//	   Calphkt=Calphit+rvk(k)*Calphakt(k); 
+//	}
+//	Cbetait=Calphit; Cbetakt=Calphkt;
+//
+//	double Cval1t,Cvalt=1,Cft; 
+//	for (k=0;k<prv;k++) if (rvi(k)+rvk(k)>0) 
+//	{
+//	Cval1t=rvi(k)*ilapgam(Calphit,Cbetait,exp(-x))+rvk(k)*ilapgam(Calphkt,Cbetakt,exp(-y)); 
+//	if (rvi(k)>0) Calpht=Calphait(k); else Calpht=Calphakt(k); 
+//	Cval1t=lapgam(Calpht,Cbetait,Cval1t); 
+//	Cvalt=Cvalt*Cval1t; 
+//	}
+//	Cft=1-exp(-x)-exp(-y);
+//	Cft=Cft+Cvalt; 
+//	dckij(i)= (Cft-ckij(0))/epsilon; 
+//	printf(" %d %lf \n",i,dckij(i)); 
+//} // }}}
+//
+
+// computation of derivatives using cx_double numbers and cx_double functions 
+// goes through the values and adds epislon*i 
+//double epsilon=0; 
+//double epsilon=1E-20; 
+epsilon=1E-20; 
+cx_double Calph,Calphi,Calphk,Cbetai,Cbetak;
+cx_vec Calphai(prv),Calphak(prv); 
+
+nn=prv; 
+for (i=0;i< prv;i++) {
+	for (k=0;k< prv;k++) {
+		Calphai(k)=cx_double(alphai(k),0); 
+		Calphak(k)=cx_double(alphak(k),0); 
+	}
+	Calphai(i)=cx_double(alphai(i),epsilon); 
+	Calphak(i)=cx_double(alphak(i),epsilon); 
+
+       // sum af alpha'er
+	Calphi=0; Calphk=0; 
+	for (k=0;k< nn;k++) {
+	   Calphi=Calphi+rvi(k)*Calphai(k); 
+	   Calphk=Calphk+rvk(k)*Calphak(k); 
+	}
+	Cbetai=Calphi; Cbetak=Calphk;
+
+	cx_double Cval1,Cval=1,Cf; 
+	for (k=0;k<prv;k++) if (rvi(k)+rvk(k)>0) 
+	{
+	Cval1=rvi(k)*Cilapgam(Calphi,Cbetai,exp(-x))+rvk(k)*Cilapgam(Calphk,Cbetak,exp(-y)); 
+	if (rvi(k)>0) Calph=Calphai(k); else Calph=Calphak(k); 
+	Cval1=Clapgam(Calph,Cbetai,Cval1); 
+	Cval=Cval*Cval1; 
+	}
+	Cf=(cx_double) 1-exp(-x)-exp(-y);
+	Cf=Cf+Cval; 
+	dckij(i)= imag(Cf)/epsilon; 
+}
+
+} // }}}
+
+void ckrvdestheta(mat &thetades,vec &theta, // {{{
+		int inverse, double x,double y,
+		vec &ckij, vec &dckij,vec &rvi,vec &rvk)
+{
+double val,val1,alphi=0,alphk=0,alph,betai,betak;
+double test=1; //lapgam(),ilapgam(),Dtlapgam(), Dalphalapgam(),Dilapgam(),Dbetalapgam(),Dbetailapgam();
+int ntheta,prv,k,nn,i; 
+//void funkdes2(); 
+
+if (test<1) {
+Rprintf("ckr \n"); 
+//print_vec(dckij); print_vec(rvk); print_vec(rvi); print_vec(alphai); print_vec(alphak); 
+}
+nn=rvi.n_rows; 
+prv=nn; 
+ntheta=theta.n_rows; 
+
+vec theta2(ntheta); 
+
+if (inverse==1)  theta2=exp(theta); else theta2=theta;
+vec alphai(prv),alphak(prv);
+alphai= thetades * theta2;
+alphak= thetades * theta2;
+
+// fix denne i CPP version
+//rvi.print("ckrv rvi"); 
+//alphai.print("alph ckrv rvi"); 
+nn=rvi.n_rows; 
+for (k=0;k< nn;k++) {
+   alphi=alphi+rvi(k)*alphai(k); 
+   alphk=alphk+rvk(k)*alphak(k); 
+}
+//alphi=sum(rvi % alphai); alphk=sum(rvk% alphak); 
+//alphi=trans(rvi) * alphai; alphk=trans(rvk) * alphak; 
+betai=alphi; betak=alphk;
+
+prv=rvi.n_rows;
+vec Dphi(prv),Dphk(prv);
+Dphi.fill(0); Dphk.fill(0); 
+
+val=1; 
 for (k=0;k<prv;k++) if (rvi(k)+rvk(k)>0) 
 {
+val1=rvi(k)*ilapgam(alphi,betai,exp(-x))+rvk(k)*ilapgam(alphk,betak,exp(-y)); 
 if (rvi(k)>0) alph=alphai(k); else alph=alphak(k); 
-val2=rvi(k)*ilapgam(alphi,betai,exp(-x))+
-     rvk(k)*ilapgam(alphk,betak,exp(-y)); 
-val1= Dtlapgam(alph,betai,val2);
-val3= lapgam(alph,betai,val2);
+val1=lapgam(alph,betai,val1); 
+val=val*val1; 
+}
+ckij(0)=1-exp(-x)-exp(-y)+val; 
 
-dckij(k)=dckij(k)+Dalphalapgam(alph,betai,val2)/val3;
-Dphi=(val1*rvi(k)*(Dilapgam(alphi,betai,exp(-x))+Dbetailapgam(alphi,betai,exp(-x)))/val3)*rvi; 
-Dphk=(val1*rvk(k)*(Dilapgam(alphk,betak,exp(-y))+Dbetailapgam(alphk,betai,exp(-y)))/val3)*rvk;
-dckij=dckij+Dphi+Dphk;
-//vec_add(Dphi,dckij,dckij); vec_add(Dphk,dckij,dckij); 
+// computation of derivatives using cx_double numbers and cx_double functions 
+// goes through the values and adds epislon*i 
+double epsilon=1E-20; 
+cx_double Calph,Calphi,Calphk,Cbetai,Cbetak;
+cx_vec Calphai(prv),Calphak(prv); 
+cx_vec Ctheta(ntheta),Ctheta2(ntheta); 
 
-Dphi=(Dbetalapgam(alph,betai,val2)/val3)*rvi;
-//vec_add(Dphi,dckij,dckij); 
-dckij=dckij+Dphi; 
-};
-dckij=val*dckij;
+nn=prv; 
+for (i=0;i< ntheta;i++) {
+     for (k=0;k< ntheta;k++) Ctheta(k)=cx_double(theta(k),0); 
+     Ctheta(i)=cx_double(theta(i),epsilon); 
+if (inverse==1)  Ctheta2=exp(Ctheta); else Ctheta2=Ctheta;
+Calphai= thetades * Ctheta2;
+Calphak= thetades * Ctheta2;
+
+       // sum af alpha'er
+	Calphi=0; Calphk=0; 
+	for (k=0;k< nn;k++) {
+	   Calphi=Calphi+rvi(k)*Calphai(k); 
+	   Calphk=Calphk+rvk(k)*Calphak(k); 
+	}
+	Cbetai=Calphi; 
+	Cbetak=Calphk;
+
+	cx_double Cval1,Cval=1,Cf; 
+	for (k=0;k<prv;k++) if (rvi(k)+rvk(k)>0) 
+	{
+	Cval1=rvi(k)*Cilapgam(Calphi,Cbetai,exp(-x))+rvk(k)*Cilapgam(Calphk,Cbetak,exp(-y)); 
+	if (rvi(k)>0) Calph=Calphai(k); else Calph=Calphak(k); 
+	Cval1=Clapgam(Calph,Cbetai,Cval1); 
+	Cval=Cval*Cval1; 
+	}
+	Cf=(cx_double) 1-exp(-x)-exp(-y);
+	Cf=Cf+Cval; 
+	dckij(i)= imag(Cf)/epsilon; 
+}
 
 } // }}}
 
@@ -838,28 +1043,38 @@ RcppExport SEXP cor(SEXP itimes,SEXP iy,SEXP icause, SEXP iCA1, SEXP iKMc,
 //		printf("2 %d \n",j); thetades.print("thetades"); theta.print("theta"); 
 //		rvvec.print("rv"); rvvec1.print("rv1"); 
 //		alphai.print("alpi"); alphaj.print("alpj");
-	       ckrvdes2(alphai,alphaj,1.0,Li,Lk,ckij,rvvec2,rvvec,rvvec1); 
-	       p11t=ckrvdesp11t(theta,thetades,inverse,Li,Lk,rvvec,rvvec1); 
+//	       ckrvdes2(alphai,alphaj,1.0,Li,Lk,ckij,rvvec2,rvvec,rvvec1); 
+	       ckrvdestheta(thetades,theta,inverse,Li,Lk,ckij,vthetascore,rvvec,rvvec1); 
+	       p11t=ckij(0); // crvdesp11t(theta,thetades,inverse,Li,Lk,rvvec,rvvec1); 
 	       p11tvec(j)=p11t; 
 //	       printf("3 %lf %lf d \n",p11t,ckij(0)); 
 	       diff=(resp2-p11t); 
 //	       rvvec2.print("rvv2");   thetades.print("td"); 
 //	       vthetascore= trans(thetades) * rvvec2; 
-//	       vthetascore.print("vthetascore"); 
-	       ckrvdes3(theta,thetades,inverse,Li,Lk,ckij,vthetascore,rvvec,rvvec1); 
+	  if (j<0)   {  Rprintf("=============================== %lf  %lf \n",p11t,ckij(0)); 
+		  alphai.print("alphai"); 
+		  rvvec2.print("rvvec2"); 
+		  vthetascore.print("vthetascore 0"); 
+	  }
+	  if (j<0)   {  Rprintf("-----------------------------  %lf   %lf \n",p11t,ckij(0)); 
+vec alphail= thetades * vtheta2;
+alphail.print("alphil"); 
+	                vthetascore.print("vthetascore 1"); 
+	  }
+	  if (j<0)   {  
+	       vthetascore.print("deriv 2"); 
+	  }
 //	       rvvec2.print("f3"); 
 //	       vM(pardes(i),rvvec2,vthetascore); 
 	       ssf=ssf+weights(i)*pow(diff,2); 
-	       }
-//	rvvec.print("rvec "); vthetascore.print("vt s"); vtheta2.print("vt 2"); 
-//      if (inverse==1)  vthetascore=vthetascore%vtheta2;
+	     }
 
 	  for (c1=0;c1<pt;c1++) 
-	  for (v1=0;v1<pt;v1++) DUtheta(c1,v1)+=weights(i)*2*vthetascore(c1)*vthetascore(v1);
+	  for (v1=0;v1<pt;v1++) DUtheta(c1,v1)+=2*weights(i)*vthetascore(c1)*vthetascore(v1);
 // kkho   DUtheta=DUtheta+weights(i)*2*(vthetascore*trans(vthetascore));
 //        vthetascore.print("vtheta"); 
-	   vthetascore=weights(i)*2*diff*vthetascore; 
-	   Utheta=Utheta+vthetascore; 
+	   vthetascore=2*weights(i)*diff*vthetascore; 
+	   Utheta=Utheta-vthetascore; 
 
 	  if (iid==1) for (c=0;c<pt;c++) thetiid(j,c)+=vthetascore(c); 
 	} // }}}
@@ -905,7 +1120,9 @@ if (j<0) Rprintf("uu2 %lf %lf %lf %lf %lf %lf %d %d \n",pbhat(i),pbhat(k),0*pbha
 	       Utheta.print("DU"); 
 	       vthetascore.print("vt"); 
        }
-       if (iid==1) for (c1=0;c1<pt;c1++) thetiid(j,c1)+=vthetascore(c1); 
+       if (iid==1)  { 
+	       for (c1=0;c1<pt;c1++) thetiid(j,c1)+=vthetascore(c1); 
+       }
    }
  } /* j in antclust */ 
  } // s < Ntimes
